@@ -132,7 +132,8 @@ A L</FieldMapInput>.
 
 =head3 subscribe
 
-Code-ref to return a given property from a given source-object.
+Code-ref to return a subscription to the field from a given
+source-object. See L<GraphQL::Subscription/subscribe>.
 
 =head3 deprecation_reason
 
@@ -394,12 +395,12 @@ declare "ExecutionPartialResult",
 
 =head2 Promise
 
-An object that has a C<then> method.
+An object that has C<then>, C<resolve>, C<reject> methods.
 
 =cut
 
 declare "Promise",
-  as HasMethods['then'];
+  as HasMethods[qw(then resolve reject)];
 
 =head2 PromiseCode
 
@@ -407,6 +408,10 @@ A hash-ref with three keys: C<resolve>, C<all>, C<reject>. The values are
 all code-refs that take one value (for C<all>, an array-ref), and create
 the given kind of Promise.
 
+Must also have a C<new> key for use with L<GraphQL::Subscription>,
+with code returning a promise that can then have C<resolve> or C<reject>
+called on it.
+
 =cut
 
 declare "PromiseCode",
@@ -414,8 +419,18 @@ declare "PromiseCode",
     resolve => CodeLike,
     all => CodeLike,
     reject => CodeLike,
+    new => Optional[CodeLike],
   ];
 
+=head2 AsyncIterator
+
+An instance of L<GraphQL::AsyncIterator>.
+
+=cut
+
+declare "AsyncIterator",
+  as InstanceOf['GraphQL::AsyncIterator'];
+
 =head1 AUTHOR
 
 Ed J, C<< <etj at cpan.org> >>
